<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Закрыть (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Развернуть</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Убрать предупреждение</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% из %Ln минут</numerusform>
            <numerusform>%1% из %Ln минут</numerusform>
            <numerusform>%1% из %Ln минут</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln слов</numerusform>
            <numerusform>%Ln слов</numerusform>
            <numerusform>%Ln слов</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Ежедневный прогресс</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Наиболее долгий период рабочих дней</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Текущий период рабочих дней</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Недоступно</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% от ежедневной цели</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Установить язык</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Без названия %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Только чтение)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Невозможно сохранить &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Невозможно перезаписать &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Переименовать файл</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Невозможно переименовать &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Перезагрузить файл?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Перезагрузить файл &apos;%1&apos; с диска?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Все несохранённые изменения в файле будут утеряны.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Открыть заново</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Без названия %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Сохранение файла как простой текст приведёт к потере форматирования. Убрать форматирование?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Файл изменён</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Файл &apos;%1&apos; был изменен в другой программе.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Открыть заново этот файл?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Открыть заново</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Пропустить</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Файл удалён</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Файл %1 был удалён другой программой.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Хотите ли вы сохранить файл, или же закрыть его?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Не учитывать регистр</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Только слова целиком</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Регулярные выражения</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Найти выше</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Найти ниже</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Заменить</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Заменить &amp;все</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Найти</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Заменить %n совпадение?</numerusform>
            <numerusform>Заменить %n совпадения?</numerusform>
            <numerusform>Заменить %n совпадений?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Фраза не найдена.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Открытый Текстовый Документ</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>Открытый текстовый документ XML</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Открытый офисный файл XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Расширенный Текстовый формат</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Обычный текст</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Все поддерживаемые файлы</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Проверить правописание...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Нет вариантов)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Открыть изображение</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Изображения(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустите программу, чтобы применить изменение языка.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Проверка правописания</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Выберите словарь</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Невозможно открыть архив.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Архив не содержит правильного словаря.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Комбинация клавиш</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Некоторые комбинации клавиш совпадают. Продолжить?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Словарь &quot;%1&quot; уже существует. Перезаписать его?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Дневная задача</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Минут:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Слов:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Редактирование</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Всегда центрировать по вертикали</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Прямоугольный курсор</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Сглаживать шрифты</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Звук пишущей машинки</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Заменять кавычки:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Двойные</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Одинарные</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Сцены</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Разделительная линия:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Сохранение</translation>
    </message>
    <message>
        <source>Automatically save changes</source>
        <translation>Автоматически сохранять изменения</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Запоминать позицию курсора</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Количество слов</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Количество страниц</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Количество абзацев</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Количество символов</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Символов:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Абзацев:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Алгоритм подсчёта слов</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Сбросить сегодняшний ежедневный прогресс на ноль?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Удалить текущий словарь?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Записывать метку байта в простых текстовых файлах</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Формат по умолчанию:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Интерфейс пользователя</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Всегда показывать полосу прокрутки</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Всегда показывать полосу вверху</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Всегда показывать полосу внизу</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Сбросить сегодняшнее</translation>
    </message>
    <message>
        <source>History</source>
        <translation>История</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Запоминать историю</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Показывать рабочие дни</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Минимальный прогресс для зачета дня в рабочий период:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Определять границы слов</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Делить количество символов на шесть</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Считать каждую букву, как слово</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Алгоритм формирования страницы</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Только значки</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Только текст</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Текст рядом со значками</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Текст под значками</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Положение текста:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Переместить вверх</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Переместить вниз</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Добавить разделитель</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Команда</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Комбинация клавиш</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Проверять орфографию при вводе</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Пропускать слова в ВЕРХНЕМ РЕГИСТРЕ</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Пропускать слова с цифрами</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Пользовательский словарь</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Неподдерживаемый файл RTF.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Неожиданный конец файла.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Стрелка вниз</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Передвинуть сцены выше</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Стрелка вверх</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Открыть/закрыть список сцен</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Показать список сцен (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Скрыть список сцен (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фильтровать</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Передвинуть сцены ниже</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Изменить размер списка сцен</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Управление сеансами</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>С&amp;еансы</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Переключиться</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Новый сеанс</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Дублировать сессию</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Переименовать сеанс</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Удалить выбранный сеанс?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Название сеанса:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Заданное имя сеанса уже используется.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Новый...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Управление...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Сбросить к значениям по умолчанию</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Комбинация клавиш:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Замена кавычек...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Проверить орфографию</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Пропустить</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>П&amp;ропустить все</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Заменить</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Заме&amp;нить все</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Нет в словаре:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Заменить на:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Проверяется орфография...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Пожалуйста, подождите</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Продолжить проверку с начала файла?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Проверка орфографии завершена.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Символы</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Недавно использованные символы</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Все символы</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Блоки</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Скрипты</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Безымянная %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Нет изображения</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Замостить</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Центрировать</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>По ширине</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Масштабировать</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Приблизить</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Непрозрачность:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Закругление углов фона текста</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Радиус:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Размытие фона текста</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Падающая тень от текста</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Вертикальное смещение:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Границы</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Окно:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Страница:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Отступ первой строки:</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Перед:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>После:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Редактировать тему</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Фон окна</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Изображение:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> пикселей</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Фон текста</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Ошибки:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Межстрочный интервал</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Одинарный</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>Полуторный</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Двойной</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Пропорциональный</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Отступы параграфа</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Ширина вкладки:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Новая тема</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Горькие небеса</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Очарование</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Нежный блюз</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Старая школа</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Космические мечты</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Шпионские игры</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Спокойствие</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Письменный стол</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новая</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Дублировать</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Пользовательская</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Импорт</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Удалить тему &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Темы (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Импортировать тему</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Экспортировать тему</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Удалить таймер?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Слов:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Страниц:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Абзацев:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Символов:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Интервал</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Заданное время</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Будильник</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Сообщение:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Таймер не включён</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Таймеры</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Недавний</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Отменить редактирование таймеров?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+ЧЧ:мм:сс</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Загружаются темы</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Загружаются звуки</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Безымянный</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>О программе FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Простой полноэкранный текстовый редактор</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущен под лицензией &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>В программе используются иконки из темы &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Используются согласно лицензии &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Символов: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Страниц: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Абзацев: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Слов: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Открывается %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Безымянный %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Список всех документов</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Перейти к следующему документу</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Перейти к предыдущему документу</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Перейти к первому документу</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Перейти к последнему документу</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Перейти к документу %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Загружаются настройки</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Резервная память недоступна для записи.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>Работа приложения была завершена неправильно.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Восстановить открытые файлы из резервной памяти?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Не удалось открыть некоторые файлы.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Некоторые файлы были открыты только для чтения.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; новее резервной копии.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Заменить новую версию резервной копией?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Сохранить изменения?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Сохранить изменения в файле &apos;%1&apos; перед закрытием?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ваши изменения будут утеряны, если вы не сохраните их.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Не удаётся загрузить звук пишущей машинки.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Откр&amp;ыть заново</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>П&amp;ереименовать...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Сохранить вс&amp;е</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Управление сеансами</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Новый сеанс</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Печать...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Ус&amp;тановки страницы...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>З&amp;акрыть</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Пов&amp;торить</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Вы&amp;резать</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Вс&amp;тавить</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Вставить без &amp;форматирования</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Выбрать всё</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Выбрать &amp;сцену</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Ф&amp;ормат</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Заголовок</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Заголовок &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Заголовок &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Заголовок &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Заголовок &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Заголовок &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Заголовок &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Нормальный</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Полу&amp;жирный</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Курсив</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Под&amp;чёркнутый</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Зачёркнутый</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Надстрочный индекс</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>П&amp;одстрочный индекс</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>По &amp;левому краю</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>По &amp;центру</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>По &amp;правому краю</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>По &amp;ширине</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>У&amp;меньшить отступ</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>У&amp;величить отступ</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Фрагмент слева напр&amp;аво</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Фрагмент справа нал&amp;ево</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Найти...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Найти следующ&amp;ий</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Найти пред&amp;ыдущий</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>За&amp;менить...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Заменить кавы&amp;чки</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Во всём &amp;документе</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Обновить умные цитаты документа</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>В &amp;выделенном</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Обновить умные цитаты выделения</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Ор&amp;фография...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Установить &amp;язык...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Таймеры...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Сим&amp;волы...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Ежедневный прогресс</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Показать панель &amp;инструментов</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Показать значки мен&amp;ю</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Подсве&amp;тка текста</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Полно&amp;экранный режим</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Сверн&amp;уть</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Темы...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Пара&amp;метры...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Отключена</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>На одной строке</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>На трёх строках</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;На абзаце</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>На абзаце</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Спр&amp;авка</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Формат некоторых файлов не поддерживается программой. Эти файлы не были открыты.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Выключено</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Одна ст&amp;рока</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Три строки</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Информация о &amp;Qt</translation>
    </message>
</context>
</TS>
